contexttools.get_staff_change_mark_attached_to_component
========================================================

.. autofunction:: abjad.tools.contexttools.get_staff_change_mark_attached_to_component.get_staff_change_mark_attached_to_component
